@@ -17,19 +17,25 @@ my $loader = Resource::Loader->new(
          cont    => 0,
          resources =>
            [
-             { name => 'never',
-               when => sub { 0 },
-               code => sub { die "this will never be loaded" },
-             },
-             { name => 'sometimes',
-               when => sub { int rand 2 > 0 }, # true 50% of the time
-               code => sub { "'sometimes' was loaded. args: [@_]" },
-               args => [ qw/foo bar baz/ ],
-             },
-             { name => 'always',
-               when => sub { 1 },
-               code => sub { "always' was loaded" },
-             },
+	    { name => 'never',
+	      when => sub { 0 },
+	      what => sub { die "this will never be loaded" },
+	    },
+	    { name => 'sometimes 50%',
+	      when => sub { int rand 2 > 0 },
+	      what => sub { "'sometimes' was loaded. args: [@_]" },
+	      whatargs => [ qw/foo bar baz/ ],
+	    },
+	    { name => 'sometimes 66%',
+	      when => sub { int rand @_ },
+	      whenargs => [ 0, 1, 2 ],
+	      what => sub { "'sometimes' was loaded. args: [@_]" },
+	      whatargs => [ qw/foo bar baz/ ],
+	    },
+	    { name => 'always',
+	      when => sub { 1 },
+	      what => sub { "always' was loaded" },
+	    },
            ],
 );
 
